@@ -11,6 +11,5 @@ from .query_booster import QueryBooster
 from .json_encoder import json_encoder
 from .json_columns import JSONEncodedStruct, MutableDict, MutableList
 from .schema_generators import generate_input_data_schema
-from . import crud_api_view, responses
-from .crud_api_view import register_crud_routes_for_models
+from .entities_router import EntitiesRouter, Entity, Get, Index, Post, Put, Patch, Delete, BatchSave
 from .interactive_shell import run_interactive_shell
\ No newline at end of file
